Model abstraction layer for liquid-edge
This module provides abstractions for different types of models that can be loaded and used with the liquid-edge inference runtime.
Traits
- Model
- Trait representing a model that can be loaded and used for inference